@@ -1,4 +1,5 @@
 import requests
+import jsw_nx as nx
 from bs4 import BeautifulSoup
 from .settings import *
 
@@ -13,9 +14,8 @@ def ncbi_download_accids(**kwargs):
     soup = BeautifulSoup(res1.text, 'html.parser')
     query_key_el = soup.select_one(QUERY_KEY)
     query_key = query_key_el.attrs['value']
-    res2 = requests.get(f'{BASE_URL}/sviewer/viewer.cgi?db=protein&report=accnlist&query_key={query_key}',
-                        stream=True,
-                        cookies=res1.cookies)
+    params = nx.param({'db': 'protein', 'report': 'accnlist', 'query_key': query_key})
+    res2 = requests.get(f'{BASE_URL}/sviewer/viewer.cgi?{params}', stream=True, cookies=res1.cookies)
 
     with open(filename, "wb") as f:
         for chunk in res2.iter_content(chunk_size=chunk_size):
